@@ -1,4 +1,4 @@
 # flake8: noqa: F401
 from .mongo_object import MongoObject
 from .base_mongo_object import BaseMongoObject
-from .utils import connect
+from .connector import connector
